summaryrefslogtreecommitdiff
path: root/src/passes/ConstHoisting.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/passes/ConstHoisting.cpp')
-rw-r--r--src/passes/ConstHoisting.cpp9
1 files changed, 3 insertions, 6 deletions
diff --git a/src/passes/ConstHoisting.cpp b/src/passes/ConstHoisting.cpp
index 17761e765..08fede1df 100644
--- a/src/passes/ConstHoisting.cpp
+++ b/src/passes/ConstHoisting.cpp
@@ -91,12 +91,9 @@ private:
size = getTypeSize(value.type);
break;
}
- case v128: {
- // v128 not implemented yet
- return false;
- }
- case exnref: {
- // exnref cannot have literals
+ case v128: // v128 not implemented yet
+ case anyref: // anyref cannot have literals
+ case exnref: { // exnref cannot have literals
return false;
}
case none: